Documentation
¶
Overview ¶
┌────────────────────────────────── WARNING ───────────────────────────────────┐ │ This "module_api.go" file was automatically generated using: │ │ https://github.com/craterdog/go-development-tools/wiki │ │ │ │ Updates to any part of this file—other than the Module Description │ │ and the Global Functions sections may be overwritten. │ └──────────────────────────────────────────────────────────────────────────────┘
Package "module" declares type aliases for the commonly used types declared in the packages contained in this module. It also provides constructors for each commonly used class that is exported by the module. Each constructor delegates the actual construction process to its corresponding concrete class declared in the corresponding package contained within this module.
For detailed documentation on this entire module refer to the wiki:
Index ¶
- func CreatePackage(moduleName string, wikiPath string, packageName string) mod.ModelLike
- func GenerateAstClass(moduleName string, className string, model mod.ModelLike) string
- func GenerateAstPackage(moduleName string, wikiPath string, syntax not.SyntaxLike) mod.ModelLike
- func GenerateClass(moduleName string, packageName string, className string, existing string, ...) string
- func GenerateFormatterClass(moduleName string, existing string, syntax not.SyntaxLike) string
- func GenerateGrammarPackage(moduleName string, wikiPath string, syntax not.SyntaxLike) mod.ModelLike
- func GenerateModule(moduleName string, wikiPath string, existing string, ...) string
- func GenerateParserClass(moduleName string, syntax not.SyntaxLike) string
- func GenerateProcessorClass(moduleName string, syntax not.SyntaxLike) string
- func GenerateScannerClass(moduleName string, syntax not.SyntaxLike) string
- func GenerateTokenClass(moduleName string, syntax not.SyntaxLike) string
- func GenerateValidatorClass(moduleName string, existing string, syntax not.SyntaxLike) string
- func GenerateVisitorClass(moduleName string, syntax not.SyntaxLike) string
- type AstSynthesizerClassLike
- type AstSynthesizerLike
- type ClassAnalyzerClassLike
- type ClassAnalyzerLike
- type ClassAssemblerClassLike
- type ClassAssemblerLike
- type ClassSynthesizerClassLike
- type ClassSynthesizerLike
- type ClassTemplateDriven
- type FormatterSynthesizerClassLike
- type FormatterSynthesizerLike
- type GrammarSynthesizerClassLike
- type GrammarSynthesizerLike
- type ModuleAssemblerClassLike
- type ModuleAssemblerLike
- type ModuleSynthesizerClassLike
- type ModuleSynthesizerLike
- type ModuleTemplateDriven
- type NodeSynthesizerClassLike
- type NodeSynthesizerLike
- type PackageAnalyzerClassLike
- type PackageAnalyzerLike
- type PackageAssemblerClassLike
- type PackageAssemblerLike
- type PackageSynthesizerClassLike
- type PackageSynthesizerLike
- type PackageTemplateDriven
- type ParserSynthesizerClassLike
- type ParserSynthesizerLike
- type ProcessorSynthesizerClassLike
- type ProcessorSynthesizerLike
- type ScannerSynthesizerClassLike
- type ScannerSynthesizerLike
- type SyntaxAnalyzerClassLike
- type SyntaxAnalyzerLike
- type TokenSynthesizerClassLike
- type TokenSynthesizerLike
- type ValidatorSynthesizerClassLike
- type ValidatorSynthesizerLike
- type VisitorSynthesizerClassLike
- type VisitorSynthesizerLike
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CreatePackage ¶
func GenerateAstClass ¶
func GenerateAstPackage ¶
func GenerateClass ¶
func GenerateFormatterClass ¶
func GenerateFormatterClass( moduleName string, existing string, syntax not.SyntaxLike, ) string
func GenerateGrammarPackage ¶
func GenerateModule ¶
func GenerateParserClass ¶
func GenerateParserClass( moduleName string, syntax not.SyntaxLike, ) string
func GenerateProcessorClass ¶
func GenerateProcessorClass( moduleName string, syntax not.SyntaxLike, ) string
func GenerateScannerClass ¶
func GenerateScannerClass( moduleName string, syntax not.SyntaxLike, ) string
func GenerateTokenClass ¶
func GenerateTokenClass( moduleName string, syntax not.SyntaxLike, ) string
func GenerateValidatorClass ¶
func GenerateValidatorClass( moduleName string, existing string, syntax not.SyntaxLike, ) string
func GenerateVisitorClass ¶
func GenerateVisitorClass( moduleName string, syntax not.SyntaxLike, ) string
Types ¶
type AstSynthesizerClassLike ¶
type AstSynthesizerClassLike = syn.AstSynthesizerClassLike
func AstSynthesizerClass ¶
func AstSynthesizerClass() AstSynthesizerClassLike
type AstSynthesizerLike ¶
type AstSynthesizerLike = syn.AstSynthesizerLike
func AstSynthesizer ¶
func AstSynthesizer( syntax not.SyntaxLike, ) AstSynthesizerLike
type ClassAnalyzerClassLike ¶
type ClassAnalyzerClassLike = ana.ClassAnalyzerClassLike
func ClassAnalyzerClass ¶
func ClassAnalyzerClass() ClassAnalyzerClassLike
type ClassAnalyzerLike ¶
type ClassAnalyzerLike = ana.ClassAnalyzerLike
func ClassAnalyzer ¶
func ClassAnalyzer( model mod.ModelLike, className string, ) ClassAnalyzerLike
type ClassAssemblerClassLike ¶
type ClassAssemblerClassLike = ass.ClassAssemblerClassLike
func ClassAssemblerClass ¶
func ClassAssemblerClass() ClassAssemblerClassLike
type ClassAssemblerLike ¶
type ClassAssemblerLike = ass.ClassAssemblerLike
func ClassAssembler ¶
func ClassAssembler() ClassAssemblerLike
type ClassSynthesizerClassLike ¶
type ClassSynthesizerClassLike = syn.ClassSynthesizerClassLike
func ClassSynthesizerClass ¶
func ClassSynthesizerClass() ClassSynthesizerClassLike
type ClassSynthesizerLike ¶
type ClassSynthesizerLike = syn.ClassSynthesizerLike
func ClassSynthesizer ¶
func ClassSynthesizer( model mod.ModelLike, className string, ) ClassSynthesizerLike
type ClassTemplateDriven ¶
type ClassTemplateDriven = ass.ClassTemplateDriven
type FormatterSynthesizerClassLike ¶
type FormatterSynthesizerClassLike = syn.FormatterSynthesizerClassLike
func FormatterSynthesizerClass ¶
func FormatterSynthesizerClass() FormatterSynthesizerClassLike
type FormatterSynthesizerLike ¶
type FormatterSynthesizerLike = syn.FormatterSynthesizerLike
func FormatterSynthesizer ¶
func FormatterSynthesizer( syntax not.SyntaxLike, ) FormatterSynthesizerLike
type GrammarSynthesizerClassLike ¶
type GrammarSynthesizerClassLike = syn.GrammarSynthesizerClassLike
func GrammarSynthesizerClass ¶
func GrammarSynthesizerClass() GrammarSynthesizerClassLike
type GrammarSynthesizerLike ¶
type GrammarSynthesizerLike = syn.GrammarSynthesizerLike
func GrammarSynthesizer ¶
func GrammarSynthesizer( syntax not.SyntaxLike, ) GrammarSynthesizerLike
type ModuleAssemblerClassLike ¶
type ModuleAssemblerClassLike = ass.ModuleAssemblerClassLike
func ModuleAssemblerClass ¶
func ModuleAssemblerClass() ModuleAssemblerClassLike
type ModuleAssemblerLike ¶
type ModuleAssemblerLike = ass.ModuleAssemblerLike
func ModuleAssembler ¶
func ModuleAssembler() ModuleAssemblerLike
type ModuleSynthesizerClassLike ¶
type ModuleSynthesizerClassLike = syn.ModuleSynthesizerClassLike
func ModuleSynthesizerClass ¶
func ModuleSynthesizerClass() ModuleSynthesizerClassLike
type ModuleSynthesizerLike ¶
type ModuleSynthesizerLike = syn.ModuleSynthesizerLike
func ModuleSynthesizer ¶
func ModuleSynthesizer( moduleName string, models com.CatalogLike[string, mod.ModelLike], ) ModuleSynthesizerLike
type ModuleTemplateDriven ¶
type ModuleTemplateDriven = ass.ModuleTemplateDriven
type NodeSynthesizerClassLike ¶
type NodeSynthesizerClassLike = syn.NodeSynthesizerClassLike
func NodeSynthesizerClass ¶
func NodeSynthesizerClass() NodeSynthesizerClassLike
type NodeSynthesizerLike ¶
type NodeSynthesizerLike = syn.NodeSynthesizerLike
func NodeSynthesizer ¶
func NodeSynthesizer( model mod.ModelLike, className string, ) NodeSynthesizerLike
type PackageAnalyzerClassLike ¶
type PackageAnalyzerClassLike = ana.PackageAnalyzerClassLike
func PackageAnalyzerClass ¶
func PackageAnalyzerClass() PackageAnalyzerClassLike
type PackageAnalyzerLike ¶
type PackageAnalyzerLike = ana.PackageAnalyzerLike
func PackageAnalyzer ¶
func PackageAnalyzer( model mod.ModelLike, ) PackageAnalyzerLike
type PackageAssemblerClassLike ¶
type PackageAssemblerClassLike = ass.PackageAssemblerClassLike
func PackageAssemblerClass ¶
func PackageAssemblerClass() PackageAssemblerClassLike
type PackageAssemblerLike ¶
type PackageAssemblerLike = ass.PackageAssemblerLike
func PackageAssembler ¶
func PackageAssembler() PackageAssemblerLike
type PackageSynthesizerClassLike ¶
type PackageSynthesizerClassLike = syn.PackageSynthesizerClassLike
func PackageSynthesizerClass ¶
func PackageSynthesizerClass() PackageSynthesizerClassLike
type PackageSynthesizerLike ¶
type PackageSynthesizerLike = syn.PackageSynthesizerLike
func PackageSynthesizer ¶
func PackageSynthesizer() PackageSynthesizerLike
type PackageTemplateDriven ¶
type PackageTemplateDriven = ass.PackageTemplateDriven
type ParserSynthesizerClassLike ¶
type ParserSynthesizerClassLike = syn.ParserSynthesizerClassLike
func ParserSynthesizerClass ¶
func ParserSynthesizerClass() ParserSynthesizerClassLike
type ParserSynthesizerLike ¶
type ParserSynthesizerLike = syn.ParserSynthesizerLike
func ParserSynthesizer ¶
func ParserSynthesizer( syntax not.SyntaxLike, ) ParserSynthesizerLike
type ProcessorSynthesizerClassLike ¶
type ProcessorSynthesizerClassLike = syn.ProcessorSynthesizerClassLike
func ProcessorSynthesizerClass ¶
func ProcessorSynthesizerClass() ProcessorSynthesizerClassLike
type ProcessorSynthesizerLike ¶
type ProcessorSynthesizerLike = syn.ProcessorSynthesizerLike
func ProcessorSynthesizer ¶
func ProcessorSynthesizer( syntax not.SyntaxLike, ) ProcessorSynthesizerLike
type ScannerSynthesizerClassLike ¶
type ScannerSynthesizerClassLike = syn.ScannerSynthesizerClassLike
func ScannerSynthesizerClass ¶
func ScannerSynthesizerClass() ScannerSynthesizerClassLike
type ScannerSynthesizerLike ¶
type ScannerSynthesizerLike = syn.ScannerSynthesizerLike
func ScannerSynthesizer ¶
func ScannerSynthesizer( syntax not.SyntaxLike, ) ScannerSynthesizerLike
type SyntaxAnalyzerClassLike ¶
type SyntaxAnalyzerClassLike = ana.SyntaxAnalyzerClassLike
func SyntaxAnalyzerClass ¶
func SyntaxAnalyzerClass() SyntaxAnalyzerClassLike
type SyntaxAnalyzerLike ¶
type SyntaxAnalyzerLike = ana.SyntaxAnalyzerLike
func SyntaxAnalyzer ¶
func SyntaxAnalyzer( syntax not.SyntaxLike, ) SyntaxAnalyzerLike
type TokenSynthesizerClassLike ¶
type TokenSynthesizerClassLike = syn.TokenSynthesizerClassLike
func TokenSynthesizerClass ¶
func TokenSynthesizerClass() TokenSynthesizerClassLike
type TokenSynthesizerLike ¶
type TokenSynthesizerLike = syn.TokenSynthesizerLike
func TokenSynthesizer ¶
func TokenSynthesizer( syntax not.SyntaxLike, ) TokenSynthesizerLike
type ValidatorSynthesizerClassLike ¶
type ValidatorSynthesizerClassLike = syn.ValidatorSynthesizerClassLike
func ValidatorSynthesizerClass ¶
func ValidatorSynthesizerClass() ValidatorSynthesizerClassLike
type ValidatorSynthesizerLike ¶
type ValidatorSynthesizerLike = syn.ValidatorSynthesizerLike
func ValidatorSynthesizer ¶
func ValidatorSynthesizer( syntax not.SyntaxLike, ) ValidatorSynthesizerLike
type VisitorSynthesizerClassLike ¶
type VisitorSynthesizerClassLike = syn.VisitorSynthesizerClassLike
func VisitorSynthesizerClass ¶
func VisitorSynthesizerClass() VisitorSynthesizerClassLike
type VisitorSynthesizerLike ¶
type VisitorSynthesizerLike = syn.VisitorSynthesizerLike
func VisitorSynthesizer ¶
func VisitorSynthesizer( syntax not.SyntaxLike, ) VisitorSynthesizerLike
Directories
¶
| Path | Synopsis |
|---|---|
|
Package "analyzer" provides classes that can analyze the abstract syntax trees (ASTs) for different languages and pull out the parts that are needed by each template-driven code synthesizer.
|
Package "analyzer" provides classes that can analyze the abstract syntax trees (ASTs) for different languages and pull out the parts that are needed by each template-driven code synthesizer. |
|
Package "assembler" provides template-based code assemblers that can assemble Go code snippets into complete Go files that conform to the Crater Dog Technologies™ Go Coding Conventions located here:
|
Package "assembler" provides template-based code assemblers that can assemble Go code snippets into complete Go files that conform to the Crater Dog Technologies™ Go Coding Conventions located here: |
|
Package "synthesizer" provides code synthesizers that extract attributes from a model and integrate them with code templates to generate working Go code fragments that are used by template driven code generators.
|
Package "synthesizer" provides code synthesizers that extract attributes from a model and integrate them with code templates to generate working Go code fragments that are used by template driven code generators. |
|
test
|
|
|
example
Package "example" provides...
|
Package "example" provides... |